@@ -263,6 +263,7 @@ from typeguard import check_type
 
 from ._jsii import *
 
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
 import aws_cdk.aws_imagebuilder as _aws_cdk_aws_imagebuilder_ceddda9d
 import constructs as _constructs_77d1e7e8
 
@@ -286,12 +287,14 @@ class ImagePipeline(
         parent_image: builtins.str,
         pipeline_name: builtins.str,
         profile_name: builtins.str,
+        additional_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
         email: typing.Optional[builtins.str] = None,
         image_recipe_version: typing.Optional[builtins.str] = None,
         instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
         platform: typing.Optional[builtins.str] = None,
         security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
+        user_data_script: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
@@ -305,12 +308,14 @@ class ImagePipeline(
         :param parent_image: The source (parent) image that the image recipe uses as its base environment. The value can be the parent image ARN or an Image Builder AMI ID
         :param pipeline_name: Name of the Image Pipeline.
         :param profile_name: Name of the instance profile that will be associated with the Instance Configuration.
+        :param additional_policies: Additional policies to add to the instance profile associated with the Instance Configurations.
         :param email: Email used to receive Image Builder Pipeline Notifications via SNS.
         :param image_recipe_version: Image recipe version (Default: 0.0.1).
         :param instance_types: List of instance types used in the Instance Configuration (Default: [ 't3.medium', 'm5.large', 'm5.xlarge' ]).
         :param platform: Platform type Linux or Windows (Default: Linux).
         :param security_groups: List of security group IDs for the Infrastructure Configuration.
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
+        :param user_data_script: UserData script that will override default one (if specified).
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__6d6bcf5899c7945cb58b58346bf98d80366aa181448ff6906fb5571aeb5620d4)
@@ -326,12 +331,14 @@ class ImagePipeline(
             parent_image=parent_image,
             pipeline_name=pipeline_name,
             profile_name=profile_name,
+            additional_policies=additional_policies,
             email=email,
             image_recipe_version=image_recipe_version,
             instance_types=instance_types,
             platform=platform,
             security_groups=security_groups,
             subnet_id=subnet_id,
+            user_data_script=user_data_script,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -367,12 +374,14 @@ class ImagePipeline(
         "parent_image": "parentImage",
         "pipeline_name": "pipelineName",
         "profile_name": "profileName",
+        "additional_policies": "additionalPolicies",
         "email": "email",
         "image_recipe_version": "imageRecipeVersion",
         "instance_types": "instanceTypes",
         "platform": "platform",
         "security_groups": "securityGroups",
         "subnet_id": "subnetId",
+        "user_data_script": "userDataScript",
     },
 )
 class ImagePipelineProps:
@@ -388,12 +397,14 @@ class ImagePipelineProps:
         parent_image: builtins.str,
         pipeline_name: builtins.str,
         profile_name: builtins.str,
+        additional_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
         email: typing.Optional[builtins.str] = None,
         image_recipe_version: typing.Optional[builtins.str] = None,
         instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
         platform: typing.Optional[builtins.str] = None,
         security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
+        user_data_script: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param component_documents: Relative path to Image Builder component documents.
@@ -405,12 +416,14 @@ class ImagePipelineProps:
         :param parent_image: The source (parent) image that the image recipe uses as its base environment. The value can be the parent image ARN or an Image Builder AMI ID
         :param pipeline_name: Name of the Image Pipeline.
         :param profile_name: Name of the instance profile that will be associated with the Instance Configuration.
+        :param additional_policies: Additional policies to add to the instance profile associated with the Instance Configurations.
         :param email: Email used to receive Image Builder Pipeline Notifications via SNS.
         :param image_recipe_version: Image recipe version (Default: 0.0.1).
         :param instance_types: List of instance types used in the Instance Configuration (Default: [ 't3.medium', 'm5.large', 'm5.xlarge' ]).
         :param platform: Platform type Linux or Windows (Default: Linux).
         :param security_groups: List of security group IDs for the Infrastructure Configuration.
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
+        :param user_data_script: UserData script that will override default one (if specified).
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__d44c3e3f51e9feef4d0a0beb4a7aeeeb7d2d753e8a9bb21f5c19a8edbdff4c88)
@@ -423,12 +436,14 @@ class ImagePipelineProps:
             check_type(argname="argument parent_image", value=parent_image, expected_type=type_hints["parent_image"])
             check_type(argname="argument pipeline_name", value=pipeline_name, expected_type=type_hints["pipeline_name"])
             check_type(argname="argument profile_name", value=profile_name, expected_type=type_hints["profile_name"])
+            check_type(argname="argument additional_policies", value=additional_policies, expected_type=type_hints["additional_policies"])
             check_type(argname="argument email", value=email, expected_type=type_hints["email"])
             check_type(argname="argument image_recipe_version", value=image_recipe_version, expected_type=type_hints["image_recipe_version"])
             check_type(argname="argument instance_types", value=instance_types, expected_type=type_hints["instance_types"])
             check_type(argname="argument platform", value=platform, expected_type=type_hints["platform"])
             check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
             check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
+            check_type(argname="argument user_data_script", value=user_data_script, expected_type=type_hints["user_data_script"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "component_documents": component_documents,
             "component_names": component_names,
@@ -440,6 +455,8 @@ class ImagePipelineProps:
             "pipeline_name": pipeline_name,
             "profile_name": profile_name,
         }
+        if additional_policies is not None:
+            self._values["additional_policies"] = additional_policies
         if email is not None:
             self._values["email"] = email
         if image_recipe_version is not None:
@@ -452,6 +469,8 @@ class ImagePipelineProps:
             self._values["security_groups"] = security_groups
         if subnet_id is not None:
             self._values["subnet_id"] = subnet_id
+        if user_data_script is not None:
+            self._values["user_data_script"] = user_data_script
 
     @builtins.property
     def component_documents(self) -> typing.List[builtins.str]:
@@ -522,6 +541,14 @@ class ImagePipelineProps:
         assert result is not None, "Required property 'profile_name' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def additional_policies(
+        self,
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]]:
+        '''Additional policies to add to the instance profile associated with the Instance Configurations.'''
+        result = self._values.get("additional_policies")
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]], result)
+
     @builtins.property
     def email(self) -> typing.Optional[builtins.str]:
         '''Email used to receive Image Builder Pipeline Notifications via SNS.'''
@@ -558,6 +585,12 @@ class ImagePipelineProps:
         result = self._values.get("subnet_id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def user_data_script(self) -> typing.Optional[builtins.str]:
+        '''UserData script that will override default one (if specified).'''
+        result = self._values.get("user_data_script")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -590,12 +623,14 @@ def _typecheckingstub__6d6bcf5899c7945cb58b58346bf98d80366aa181448ff6906fb5571ae
     parent_image: builtins.str,
     pipeline_name: builtins.str,
     profile_name: builtins.str,
+    additional_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
     email: typing.Optional[builtins.str] = None,
     image_recipe_version: typing.Optional[builtins.str] = None,
     instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
     platform: typing.Optional[builtins.str] = None,
     security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
     subnet_id: typing.Optional[builtins.str] = None,
+    user_data_script: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -617,12 +652,14 @@ def _typecheckingstub__d44c3e3f51e9feef4d0a0beb4a7aeeeb7d2d753e8a9bb21f5c19a8edb
     parent_image: builtins.str,
     pipeline_name: builtins.str,
     profile_name: builtins.str,
+    additional_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
     email: typing.Optional[builtins.str] = None,
     image_recipe_version: typing.Optional[builtins.str] = None,
     instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
     platform: typing.Optional[builtins.str] = None,
     security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
     subnet_id: typing.Optional[builtins.str] = None,
+    user_data_script: typing.Optional[builtins.str] = None,
 ) -> None:
     """Type checking stubs"""
     pass
